# rpm spec from https://github.com/rpm-software-management/drpm
%bcond_with zstd

Name:           drpm
Version:        0.5.2
Release:        1
Summary:        A library for making, reading and applying deltarpm packages
# the entire source code is LGPLv2+, except src/drpm_diff.c and src/drpm_search.c which are BSD
License:        LGPLv2+ and BSD
URL:            https://github.com/rpm-software-management/%{name}
Source:         %{url}/releases/download/%{version}/%{name}-%{version}.tar.bz2

BuildRequires:  cmake >= 2.8.5 gcc zlib-devel bzip2-devel xz-devel rpm-devel openssl-devel 
BuildRequires:  libcmocka-devel >= 1.0 gdb-headless doxygen pkgconfig
%if %{with zstd}
BuildRequires:  zstd-devel
%endif
%ifarch %{ix86} x86_64 aarch64
BuildRequires:  valgrind
%endif

%description
The drpm package provides a library for making, reading and applying deltarpms,
compatible with the original deltarpm packages.

%package devel
Summary:        C interface for the drpm library
Requires:       %{name}%{?_isa} = %{version}-%{release}

%description devel
The drpm-devel package provides a C interface (drpm.h) for the drpm library.

%package help
Summary:        Documents for %{name}
Buildarch:      noarch

%description help
Documents for %{name} 

%prep
%autosetup
mkdir build

%build
pushd build
%cmake .. -DWITH_ZSTD:BOOL=%{?with_zstd:ON}%{!?with_zstd:OFF}
%make_build
make doc
popd

%install
pushd build
%make_install
popd

%check
pushd build
#ctest -VV
popd

%files
%{_libdir}/lib%{name}.so.*
%license COPYING LICENSE.BSD

%files devel
%{_libdir}/lib%{name}.so
%{_includedir}/%{name}.h
%{_libdir}/pkgconfig/%{name}.pc

%files help
%doc build/doc/html/

%changelog
* Tue Jul 18 2023 wangjiang <wangjiang37@h-partners.com> - 0.5.2-1
- Type:enhancement
- ID:NA
- SUG:NA
- DESC:upgrade version to 0.5.2

* Wed Jun 22 2022 tanyulong <tanyulong@kylinso.cn> - 0.5.1-1
- Type:requirements
- ID:NA
- SUG:NA
- DESC:upgrade upstream version 0.5.1

* Fri May 13 2022 mylee <liweiganga@uniontech.com> - 0.5.0-3
- fix spec changelog date

* Tue Apr 26 2022 renhongxun <renhongxun@h-partners.com> - 0.5.0-2
- Type:update
- ID:NA
- SUG:NA
- DESC:rebuild drpm

* Fri Jul 24 2020 zhangxingliang <zhangxingliang3@huawei.com> - 0.5.0-1
- Type:update
- ID:NA
- SUG:NA
- DESC:update to 0.5.0

* Sat Mar 14 2020 openEuler Buildteam <buildteam@openeuler.org> - 0.4.1-3
- fixbug in self-building

* Thu Sep 19 2019 Yalong Guan <guanyalong@huawei.com> 0.4.1-2
- Small spec improvements 

* Wed Sep 11 2019 Neal Gompa <ngompa13@gmail.com> 0.4.1-1
- Relicense to LGPLv2+

* Wed Aug 14 2019 Neal Gompa <ngompa13@gmail.com> 0.4.0-1
- Add support for zstd drpms
- CMake cleanups
- Make running tests optional
- Small spec improvements

* Tue May 3 2016 Matej Chalk <mchalk@redhat.com> 0.3.0-3
- Now contains makedeltarpm and applydeltarpm functionality
- Added lzlib-devel dependency for OpenSUSE

* Tue Apr 12 2016 Igor Gnatenko <ignatenko@redhat.com> - 0.3.0-2
- Cleanup spec
- Make build out-of-tree
- Sync with valgrind arches
- Build documentation

* Thu Sep 3 2015 Matej Chalk <mchalk@redhat.com> 0.3.0-1
- Bumped minor version (deltarpm creation added)

* Tue Aug 4 2015 Matej Chalk <mchalk@redhat.com> 0.2.1-1
- Added openssl dependency

* Fri Jul 24 2015 Matej Chalk <mchalk@redhat.com> 0.2.0-2
- Fixed bug in test suite

* Tue Jun 23 2015 Matej Chalk <mchalk@redhat.com> 0.2.0-1
- Bumped minor version

* Fri Jun 19 2015 Matej Chalk <mchalk@redhat.com> 0.1.3-4
- Memory test only for architectures that have valgrind (#1232157)

* Wed Mar 11 2015 Matej Chalk <mchalk@redhat.com> 0.1.3-3
- Added cmocka and valgrind package dependencies

* Fri Mar 6 2015 Matej Chalk <mchalk@redhat.com> 0.1.3-2
- Added check section

* Fri Feb 13 2015 Matej Chalk <mchalk@redhat.com> 0.1.3-1
- Bumped version to 0.1.3
- Added CMake tool

* Fri Dec 19 2014 Matej Chalk <mchalk@redhat.com> 0.1.2-4
- Enabled hardened build

* Mon Dec 15 2014 Matej Chalk <mchalk@redhat.com> 0.1.2-3
- Added unversioned .so to package to enable linking with -ldrpm

* Thu Dec 11 2014 Matej Chalk <mchalk@redhat.com> 0.1.2-2
- Removed unversioned .so from package
- Included copies of both GPLv3 and LGPLv3

* Wed Dec 3 2014 Matej Chalk <mchalk@redhat.com> 0.1.2-1
- Bumped version to 0.1.2
- Added drpm.pc file for pkgconfig tool

* Thu Nov 6 2014 Matej Chalk <mchalk@redhat.com> 0.1.1-1
- Bumped version to 0.1.1

* Wed Nov 5 2014 Matej Chalk <mchalk@redhat.com> 0.1.0-1
- Initial RPM release
